Represents all the information needed to render a single frame of a VR scene
Monotonically increasing value that allows the author
to determine if position state data been updated from the hardware
major order column matrix describing the projection to be used for the left eye’s rendering
major order column matrix describing the view transform to be used for the left eye’s rendering
major order column matrix describing the projection to be used for the right eye’s rendering
major order column matrix describing the view transform to be used for the right eye’s rendering
VRPose containing the future predicted pose of the VRDisplay
when the current frame will be presented.
Returns the "default value" for a type. Read more
Performs copy-assignment from source. Read more
Formats the value using the given formatter. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
Mutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static