The VRPose struct represents a sensor’s state at a given timestamp.
Position of the VRDisplay as a 3D vector.
May be None if the sensor is incapable of providing positional data.
Linear velocity of the sensor given in meters per second.
May be None if the sensor is incapable of providing linear velocity data.
Linear acceleration of the sensor given in meters per second squared.
May be None if the sensor is incapable of providing linear acceleration data.
Orientation of the sensor as a quaternion.
May be None if the sensor is incapable of providing orientation.
Angular velocity of the sensor given in radians per second.
May be None if the sensor is incapable of providing angular velocity data.
Linear acceleration of the sensor given in radians per second squared.
May be None if the sensor is incapable of providing angular acceleration data.
Performs copy-assignment from source. Read more
Returns the "default value" for a type. Read more
Formats the value using the given formatter. Read more
Creates owned data from borrowed data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (toowned_clone_into)
recently added
Uses borrowed data to replace owned data, usually by cloning. Read more
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Immutably borrows from an owned value. Read more
🔬 This is a nightly-only experimental API. (get_type_id)
this method will likely be replaced by an associated static
🔬 This is a nightly-only experimental API. (try_from)
The type returned in the event of a conversion error.
🔬 This is a nightly-only experimental API. (try_from)
Mutably borrows from an owned value. Read more